mchammer.Molecule
=================

.. currentmodule:: mchammer

.. autoclass:: Molecule
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Molecule.get_atoms
      ~Molecule.get_bonds
      ~Molecule.get_centroid
      ~Molecule.get_num_atoms
      ~Molecule.get_position_matrix
      ~Molecule.get_subunits
      ~Molecule.with_displacement
      ~Molecule.with_position_matrix
      ~Molecule.write_pdb_file
      ~Molecule.write_xyz_content
      ~Molecule.write_xyz_file
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Molecule.atoms
      ~Molecule.bonds
      ~Molecule.position_matrix
   
   